import express from "express";
import path from "path";
import cors from "cors";

const PORT = process.env.PORT ? +process.env.PORT : 3500;
const spritesDirectory = process.env.SPRITES_DIR || "./sprites";
const allowedOrigin = process.env.ALLOWED_ORIGIN;
const app = express();
app.listen(PORT, () => console.log(`[Express] Listening on port ${PORT}`));
app.use(cors({ origin: allowedOrigin }));
app.use(express.json());
app.use("/", require("./api"));
app.use("*", express.static(path.resolve(__dirname, "..", "build")));
app.use(
  "/public",
  express.static(path.resolve(__dirname, "..", spritesDirectory))
);

// error handling endware
app.use((err: any, req: any, res: any, next: any) => {
  console.error(err);
  res.status(err.status || 500).send(err.message || "Internal server error.");
  next();
});
